@@ -155,7 +155,7 @@ rdaFit <- function(X, Y, Z, scale = FALSE, ...) {
         }
     }
     ## Only one type of scores: return a matrix instead of a list
-    if (length(sol) == 1)
+    if (length(sol) == 1L)
         sol <- sol[[1]]
     sol
 }
